/* -*- mode: c++; c-basic-offset: 4; -*- */
#include "lmsg/Buffer.hh"
#include "lmsg/BufferPool.hh"
#include "lmsg/Message.hh"
#include "lmsg/ErrorList.hh"
#include "lmsg/Socket.hh"
#include "lmsg/SocketPool.hh"
#include "lmsg/TransportMsg.hh"
#include "lmsg/TransInput.hh"
#include "lmsg/TransOutput.hh"
#include <iostream>

using namespace lmsg;
using namespace std;

//======================================  Constructor
TransportMsg::TransportMsg(void) 
    : mFlags(0), mSocket(0), mBuffPool(&defaultLMsgBufferPool),
      mDebug(0), mReplyAddr(0) 
{
}

//======================================  Destructor
TransportMsg::~TransportMsg(void) {
}

//======================================  Get socket address
MsgAddr 
TransportMsg::getAddr(void) const {
    if (isOpen()) return mSocket->getAddr();
    else          return MsgAddr();
}

//======================================  Wait for a message on a listed socket
error_type 
TransportMsg::waitAny(wtime_type timeout, int N, const TransportMsg* list[]) {
    if (N <= 0) return NotOpen;
    const Socket** sList = new const Socket*[N];
    int nOpen = 0;
    for (int i=0 ; i<N ; i++) {
        if (list[i]->isOpen()) sList[nOpen++] = list[i]->mSocket;
    }
    error_type rc =  Socket::waitAny(timeout, nOpen, sList);
    delete[] sList;
    return rc;
}

//======================================  Set the buffer pool Address
void 
TransportMsg::setBufferPool(BufferPool* pool) {
    mBuffPool = pool;
}

//======================================  Set the debug level
void 
TransportMsg::setDebug(index_type level) {
    mDebug = level;
    if (isOpen()) mSocket->setDebug(level);
}

//======================================  Set the reply address
void 
TransportMsg::setReplyAddr(const MsgAddr& rep) {
    mReplyAddr = rep;
}
